/*******************************************************************************
 * Copyright (c) 2010, 2014 INRIA-CNRS (Espresso/TEA team).
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Loic Besnard, Francois Fabre, Thierry Gautier: Initial API and implementation and/or initial documentation
 */

package fr.inria.tea.ssme.polychrony.traceability;

/**
 * This class contains all the error messages displayable on the diagram that don't come directly from the compiler.
 */
public class ErrorMessages {
	
	public static final String	CYCLE_DETECTION							= "A Cyclic Definition Exception has been detected. The following element is defined by its own result : ";
	public static final String	INCORRECT_NAME							= "The name of this entity is not correct. Please, check that it is not a keyword of the language or a name with spaces. Name : ";
	public static final String	NO_NAME									= "The name of this entity must be set.";
	public static final String	ARRAY_DIMENSION_VALUE					= "Error in parsing the array dimension value : ";
	public static final String	SOURCE_FIELD							= "Error in the source signal name or in the 'Src Field' attribute.";
	public static final String	OPERATOR_INITIAL_VALUE					= "Error in parsing the initial value of the operator : ";
	public static final String	SIGNAL_INITIAL_VALUE					= "Error in parsing the initial value of the signal : ";
	public static final String	DESTINATION_FIELD						= "Error in the destination signal name or in the 'Dst Field' attribute.";
	public static final String	ENUM_VALUE								= "Error in parsing the enumerated value : ";
	public static final String	LITERAL_VALUE							= "Error in parsing the value of the literal.";
	
	
	public static final String	AFFECTATION_TARGET						= "The Affectation Operator must be the target of two and only two signals.";
	public static final String	ARRAY_ENUMERATION_INPUT_PORTS_NUMBER	= "The Array Enumeration operator must have at least two Input Ports. Array Enumeration operator : ";
	public static final String	ASSERTION_CLOCK_CONSTRAINTS_SOURCE		= "A Clock Relation cannot have an Assertion Clock Constraint Operator as source : ";
	public static final String	ASSERTION_CLOCK_CONSTRAINTS_TARGET		= "The Assertion Clock Constraint Operator must be the target of at least two Clock Relation link : ";
	public static final String	ASSERTION_NO_BOOLEAN_EXPRESSION			= "The Assertion must have a boolean expression expressed either in a textual form in its expression attribute, or through the use of a Condition link : ";
	public static final String	ASSERTION_INCORRECT_TXT_EXPR_ATTR		= "The textual expression attribute of the Assertion is not correct : ";
	public static final String	ASSERTION_NO_INPUT						= "Assertion doesn't have any source : ";
	public static final String	ASSERTION_TOO_MANY_INPUTS				= "Assertion has too much sources : ";
	public static final String	AUTOMATON_STATES_NAMES					= "Each state of the Automaton must have a different name (Automaton name / state name) : ";
	public static final String	AUTOMATON_REINIT_CONDITION				= "Internal Error: problem to evaluate reinit condition for Automaton : ";
	public static final String	BASIC_ITERATE_INCORRECT_ITERATOR_NAME	= "The iterator name of the BasicIterate is not correctly set : ";
	public static final String	BASIC_ITERATE_UPPER_BOUND_ANALYSIS		= "The Upper Bound attribute of the BasicIterate cannot be analysed correctly : ";
	public static final String	BASIC_ITERATE_UPPER_BOUND_NO_NAME		= "The Upper Bound attribute of a BasicIterate Block must be set : ";
	public static final String	BOOLEAN_EXPRESSION_EMPTY_ATTRIBUTE		= "The expression attribute of the Boolean Expression must be filled : ";
	public static final String	BOOLEAN_EXPRESSION_INCORRECT_ATTRIBUTE	= "The expression attribute of the Boolean Expression is not correct : ";
	public static final String	CARTESIAN_PRODUCT_NUMBER_OF_PORTS		= "The Cartesian Product must have as many Input Ports than Output Ports, and at least two of each kind of ports : ";
	public static final String	CASE_CONNECTION_LOWER_BOUND				= "Error in parsing the lower bound of CaseConnection : ";
	public static final String	CASE_CONNECTION_UPPER_BOUND				= "Error in parsing the upper bound of CaseConnection : ";
	public static final String	CELL_INITIAL_VALUE						= "Error in parsing the initial value of the Cell operator : ";
	public static final String	CELL_NO_TARGET							= "The Cell operator must be the target of (at least) one Condition link : ";
	public static final String	CLOCK_CONSTRAINTS_SOURCE				= "The Clock Relation cannot have a Clock Constraint Operator as source : ";
	public static final String	CLOCK_CONSTRAINTS_TARGET				= "A Clock Constraint Operator must be the target of at least two Clock Relation links.";
	public static final String	CONSTANT_REF_NO_REFERENCE				= "A Constant Reference must refer a declared constant value or parameter.";
	public static final String	CONSTANT_VALUE_ARRAY_DIMENSION_VALUE	= "Error in parsing the array dimension value : ";
	public static final String	CONSTANT_VALUE_VALUE					= "Error in parsing the value : ";
	public static final String	DELAY_INSTANTS_NUMBER					= "Error in parsing the number of instants of delay.";
	public static final String	DELAY_INITIAL_VALUE						= "Error in parsing the initial value of the Delay operator : ";
	public static final String	DEPENDENCE_DESTINATION_SOURCE			= "If the destination is a Dependence Operator, the source cannot be also a Dependence Operator.";
	public static final String	DEPENDENCE_TARGET						= "The Dependence Operator must be the target of two and only two signals.";
	public static final String	ENUMERATION_TYPE_NO_VALUE				= "An enumerated value cannot be an empty string";
	public static final String	ENUMERATION_VALUE_INCORRECT_NAME		= "Error in parsing the value of enumerated type name.";
	public static final String	EXTRACTION_TARGET						= "The extraction operator must be the target of one Condition link : ";
	public static final String	EXTRACTION_SOURCE						= "The extraction operator cannot have a Clock Relation link as Input : ";
	public static final String	EXTRACTION_DATAFLOW_CONNECTIONS_NUMBER	= "The extraction operator cannot have more than one DataflowConnections as input : ";
	public static final String	IFTHENELSE_TARGET						= "The If-Then-Else operator must have three Input Ports : ";
	public static final String	INDEX_FROM								= "Error when parsing the 'From' attribute. It has to be a numeric expression, or the name of an integer constant.";
	public static final String	INDEX_TO								= "Error when parsing the 'To' attribute. It has to be a numeric expression, or the name of an integer constant.";
	public static final String	INDEX_STEP								= "Error when parsing the 'Step' attribute. It has to be a numeric expression, or the name of an integer constant.";
	public static final String	INDEX_FROM_TO							= "The 'From' and the 'To' attributes must be filled with a numeric expression, or the name of an integer constant.";
	public static final String	INPUT_SOURCE							= "No DataflowConnection can target an Input Signal.";
	public static final String	INPUT_PORT_DATAFLOW_CONNECTIONS_NUMBER	= "An Input Port of a dataflow operator or iteration block must be the target of one and only Dataflow Connection link.";
	public static final String	INPUT_PORT_CLOCK_RELATION_LINKS_NUMBER	= "An Input Port of a clock operator must be the target of one and only Clock Relation link.";
	public static final String	ITERATE_INPUT_PORT						= "The Iterate block must have at least one Input Port : ";
	public static final String	MODEL_INSTANCE_PARAMETERS_NUMBER		= "The number of instantiated parameters is not the same than these of the model declaration.";
	public static final String	MODEL_INSTANCE_INPUT_SIGNALS_NUMBER		= "The number of instantiated input signals is not the same than these of the model declaration.";
	public static final String	MODEL_INSTANCE_OUTPUT_SIGNALS_NUMBER	= "The number of instantiated output signals is not the same than these of the model declaration.";
	public static final String	MODEL_INSTANCE_NO_REFERRED_PARAMETER	= "The model instance needs a referred parameter to instantiate which are of the type of the referred interface.";
	public static final String	MODEL_INSTANCE_NO_REFERRED_INTERFACE	= "A referred interface (Model Type or Model Declaration) must be specified for Model Instance : ";
	public static final String	MODEL_REF_NO_REFERRED_MODEL_DECLARATION	= "A Model Reference must refer a Model Declaration.";
	public static final String	NUMERIC_EXPRESSION_EMPTY_ATTRIBUTE		= "The Numeric Expression 'Expression' attribute is empty.";
	public static final String	NUMERIC_EXPRESSION_INCORRECT_ATTRIBUTE	= "Error in parsing the 'Expression' attribute of the operator : ";
	public static final String	PARAMETER_TYPE							= "Error in parsing the 'Type' attribute of the operator.";
	public static final String	PARAMETER_INSTANCE_INCORRECT_LINK		= "A Constant Affectation link must be connected to the Parameter Instance : ";
	public static final String	PRAGMA_NO_ATTRIBUTE						= "The 'Pragma' attribute is not filled.";
	public static final String	PRAGMA_INCORRECT_ATTRIBUTE				= "Error in parsing the 'Pragma' attribute.";
	public static final String	SIGNAL_REF_INCORRECT_REFERENCE			= "A Signal Reference must refer a declared signal.";
	public static final String	STATE_NOT_IMPLEMENTED					= "This case is not implemented yet.";
	public static final String	SWITCH_SEVERAL_ELSE						= "There are several Else Case Connection links on the Switch operator : ";
	public static final String	SWITCH_NOT_IMPLEMENTED					= "The use of the 'Src Field' is not yet implemented for the Switch operator.";
	public static final String	TRANSITION_SOURCE_DESTINATION			= "The transition needs a source and a destination state or history : ";
	public static final String	TRANSITION_INCORRECT_GUARD				= "Error in parsing the 'Guard' attribute of the transition  : ";
	public static final String	TUPLE_OPERATOR_INPUT_PORTS_NUMBER		= "The Tuple Operator must have at least two Input Ports : ";
	public static final String	TWO_INPUTS_OPERATOR_BRANCHES			= "One or both branches of the operator has error : ";
	public static final String	WINDOW_INCORRECT_SIZE_ATTRIBUTE			= "Error in parsing the 'Window Size' attribute of the Window operator : ";
}
